Chatbot-specific tools shared across bot platforms (QQ, Feishu, etc.).
Re-exports
pub use send_file::SendFileTool;
Modules
- send_
file send_filetool — sends a local file or image to the chat user.
Chatbot-specific tools shared across bot platforms (QQ, Feishu, etc.).
pub use send_file::SendFileTool;send_file tool — sends a local file or image to the chat user.